@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintSession.cpp 7083 2007-06-14 12:19:32Z chpe $
+ *  $Id: GeckoPrintSession.cpp 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -98,17 +98,13 @@ GeckoPrintSession::GetSourceFile (nsACString &aSource)
 }
 
 nsresult
-GeckoPrintSession::SetSettings (nsIPrintSettings *aPrintSettings,
-                                GtkPrintSettings *aSettings,
+GeckoPrintSession::SetSettings (GtkPrintSettings *aSettings,
 				GtkPageSetup *aPageSetup,
 				GtkPrinter *aPrinter)
 {
-  NS_ASSERTION (!mPrintSettings && !mSettings && !mPageSetup && !mPrinter, "Already have settings!");
+  NS_ASSERTION (!mSettings && !mPageSetup && !mPrinter, "Already have settings!");
 
-  NS_ENSURE_ARG (aPrintSettings);
   NS_ENSURE_ARG (aSettings);
-
-  mPrintSettings = aPrintSettings;
   mSettings = (GtkPrintSettings *) g_object_ref (aSettings);
 
   NS_ENSURE_ARG (aPageSetup);
@@ -566,15 +562,10 @@ GeckoPrintSession::GetProcessCanceledByUser (PRBool *aProcessCanceledByUser)
   *aProcessCanceledByUser = mCancelled;
   return NS_OK;
 }
-
 NS_IMETHODIMP
 GeckoPrintSession::SetProcessCanceledByUser (PRBool aProcessCanceledByUser)
 {
   mCancelled = aProcessCanceledByUser;
-  if (mPrintSettings) {
-    mPrintSettings->SetIsCancelled (aProcessCanceledByUser);
-  }
-
   return NS_OK;
 }
 
