@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-stock-icons.h 6761 2006-12-19 17:03:22Z lferrett $
+ *  $Id: ephy-stock-icons.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -27,6 +27,7 @@ G_BEGIN_DECLS
 
 #define EPHY_STOCK_POPUPS	   "popup-hidden"
 #define EPHY_STOCK_HISTORY         "history-view"
+#define EPHY_STOCK_BOOKMARK        "bookmark-web"
 #define EPHY_STOCK_BOOKMARKS       "bookmark-view"
 #define EPHY_STOCK_ENTRY	   "location-entry"
 #define EPHY_STOCK_DOWNLOAD	   "download"
@@ -35,7 +36,6 @@ G_BEGIN_DECLS
 #define STOCK_NEW_WINDOW           "window-new"
 #define STOCK_SEND_MAIL            "mail-forward"
 #define STOCK_ADD_BOOKMARK         "bookmark-new"
-#define STOCK_BOOKMARK             "stock_bookmark"
 #define STOCK_PRINT_SETUP          "stock_print-setup" /*document-page-setup*/
 #define STOCK_LOCK_INSECURE        "stock_lock-open"
 #define STOCK_LOCK_SECURE          "stock_lock"
