@@ -15,9 +15,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-properties.c 6778 2007-01-02 19:47:49Z diegoe $
+ *  $Id: ephy-bookmark-properties.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -514,7 +514,7 @@ ephy_bookmark_properties_constructor (GType type,
 	properties = EPHY_BOOKMARK_PROPERTIES (object);
 	priv = properties->priv;
 
-	gtk_window_set_icon_name (window, STOCK_BOOKMARK);
+	gtk_window_set_icon_name (window, EPHY_STOCK_BOOKMARK);
 	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_NORMAL);
 
 	g_signal_connect (properties, "response",
