@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: popup-commands.c 7014 2007-04-24 19:45:19Z diegoe $
  */
 
 #include "config.h"
@@ -175,32 +175,16 @@ save_property_url_completed_cb (EphyEmbedPersist *persist)
 				EPHY_EMBED_PERSIST_ASK_DESTINATION))
 	{
 		const char *dest;
-		char *desktop_dir; 
 		guint32 user_time;
-		GnomeVFSURI *parent, *uri, *desktop;
 
 		user_time = ephy_embed_persist_get_user_time (persist);
 		dest = ephy_embed_persist_get_dest (persist);
+
 		g_return_if_fail (dest != NULL);
 
-		desktop_dir = ephy_file_desktop_dir ();
+		/* If save location is the desktop, nautilus will not open */
+		ephy_file_browse_to (dest, user_time);
 
-		/* Where are we going to save */
-		uri = gnome_vfs_uri_new (dest); 
-		desktop = gnome_vfs_uri_new (desktop_dir);
-
-		g_return_if_fail (uri != NULL);
-
-		parent = gnome_vfs_uri_get_parent (uri);
-
-		/* If save location is the desktop, don't open it */
-		if (!gnome_vfs_uri_equal (desktop, parent))
-			ephy_file_browse_to (dest, user_time);
-
-		g_free (desktop_dir);
-		gnome_vfs_uri_unref (uri);
-		gnome_vfs_uri_unref (parent);
-		gnome_vfs_uri_unref (desktop);
 	}
 }
 
